import sys
import requests
print("sys.version: "+ sys.version)
print("sys.path: "+ str(sys.path))

class TestRequest:
    def __init__(self, url) -> None:
        self.url = url
        pass
    def get(self) -> str:
        r = requests.get(self.url)
        if(r.status_code == 200):
            return r.text
        return ""



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="first-pkg-joeyding", # Replace with your own username
    version="0.0.1",
    author="Joeyding",
    author_email="joeyding@tencent.com",
    description="A small example package",
    long_description=long_description,
    long_description_content_type="text/markdown",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    package_data = {
        # If any package contains *.txt or *.rst files, include them:
        '': ['*.txt', '*.rst']
    },
    install_requires = ['requests>=2.0'],
    python_requires='>=3.6',
)